Jobcan
======

Script for jobcan automation.

Install
-------
.. code-block:: bash

    pip install jobcan


Usage
-----

.. code-block:: bash

    Usage: jobcan [OPTIONS] COMMAND USER PASSWORD GROUP_ID



LICENSE
-------
MIT